<p align="center">
  <img alt="CADDIE Logo" src="https://github.com/Maiykol/caddiepy/blob/main/caddie_logo.png?raw=true" />
</p>


# caddiepy

The python package to the Cancer Driver Drug Interaction Explorer (CADDIE)
